pub struct Path<T>(pub T);Expand description
Route path parameters decoded into T by field name.
Tuple Fields
0: TTrait Implementations
impl<T: Eq> Eq for Path<T>
Sourceimpl<P, T> FromRequest<P> for Path<T>where
P: ?Sized,
T: DeserializeOwned + 'static,
impl<P, T> FromRequest<P> for Path<T>where
P: ?Sized,
T: DeserializeOwned + 'static,
Sourcefn from_request<'a>(
_provider: &'a P,
_context: &'a mut InvocationContext,
request: &'a HandleRequest,
) -> ExtractorFuture<'a, Self>
fn from_request<'a>( _provider: &'a P, _context: &'a mut InvocationContext, request: &'a HandleRequest, ) -> ExtractorFuture<'a, Self>
Extracts this value or rejects dispatch before the handler runs.
impl<T: PartialEq> StructuralPartialEq for Path<T>