Module testing

Module testing 

Socket-free testing tools for authored HTTP Endpoint Plugins.

Structs

EndpointTest
A direct test harness for one authored Endpoint Plugin.
TestRequest
One direct request being prepared for an EndpointTest.
TestResponse
A response returned by EndpointTest.

Enums

EndpointTestError
A failure to construct or directly invoke an Endpoint test request.