pub enum EndpointTestError {
UnknownRoute(String),
Domain(HandleError),
Runtime(RuntimeFailure),
}Expand description
A failure to construct or directly invoke an Endpoint test request.
Variants
UnknownRoute(String)
No authored route has the requested stable identifier.
Domain(HandleError)
The Endpoint intentionally returned a Capability-domain error.
Runtime(RuntimeFailure)
The Endpoint could not complete because its runtime failed.