pub struct TestRequest<'a, P> { /* private fields */ }Expand description
One direct request being prepared for an EndpointTest.
Implementations
Sourceimpl<P> TestRequest<'_, P>where
P: HttpEndpoint,
impl<P> TestRequest<'_, P>where
P: HttpEndpoint,
Sourcepub fn json(self, value: &impl Serialize) -> Result<Self, Error>
pub fn json(self, value: &impl Serialize) -> Result<Self, Error>
Serializes a JSON body and supplies its content type.
Sourcepub fn query(self, value: &impl Serialize) -> Result<Self, Error>
pub fn query(self, value: &impl Serialize) -> Result<Self, Error>
Encodes typed URL query parameters.
Sourcepub fn path_parameter(
self,
name: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn path_parameter( self, name: impl Into<String>, value: impl Into<String>, ) -> Self
Supplies one path parameter and expands it in the declared path template.
Sourcepub fn header(self, name: impl Into<String>, value: impl Into<String>) -> Self
pub fn header(self, name: impl Into<String>, value: impl Into<String>) -> Self
Supplies one request header.
Sourcepub async fn send(self) -> Result<TestResponse, EndpointTestError>
pub async fn send(self) -> Result<TestResponse, EndpointTestError>
Invokes the Endpoint directly and returns its intentional HTTP response.