pub type EndpointFuture = NativeRequestFuture<EndpointHandle>;Expand description
Boxed local handler result used by an authored HTTP Endpoint.
Aliased Type
#[repr(transparent)]pub struct EndpointFuture { /* private fields */ }pub type EndpointFuture = NativeRequestFuture<EndpointHandle>;Boxed local handler result used by an authored HTTP Endpoint.
#[repr(transparent)]pub struct EndpointFuture { /* private fields */ }