#[endpoint]Expand description
Generates one HTTP Endpoint provider from handler route attributes.
Supported handler attributes are get, post, put, patch, delete,
head, and options. Each accepts a stable route ID and path.
#[endpoint]Generates one HTTP Endpoint provider from handler route attributes.
Supported handler attributes are get, post, put, patch, delete,
head, and options. Each accepts a stable route ID and path.