Socket-free testing tools for authored HTTP Endpoint Plugins.
Structs
- Endpoint
Test - A direct test harness for one authored Endpoint Plugin.
- Test
Request - One direct request being prepared for an
EndpointTest. - Test
Response - A response returned by
EndpointTest.
Enums
- Endpoint
Test Error - A failure to construct or directly invoke an Endpoint test request.